@@ -1,6 +1,6 @@
 package Bundle::DadaMail;
 
-$VERSION = '0.0.4';
+$VERSION = '0.0.5';
 
 1;
 
@@ -32,6 +32,8 @@ L<http://dadamailproject.com>
 
 =head1 CONTENTS
 
+parent
+
 LWP - So many things. Makes the Send a Webpage work, for starters.  actually a required module, but we assume the environment Dada Mail is installed on has this already (I know, never assume!)
 
 IO::Socket::SSL
@@ -52,6 +54,8 @@ DateTime::Event::Recurrence - used for scheduled mass mailings
 
 DateTime - same
 
+File::Find::Rule - used for the Perl connector in KCFInder
+
 HTML::Tree - used for Dada Mail's "Magic" templates, as well as manipulating HTML documents
 
 HTML::Element - same
@@ -68,8 +72,6 @@ JSON - actually required for Dada Mail - Pure Perl version included, but you pro
 
 MIME::Base64
 
-Net::DNS;
-
 Text::CSV - actually required for Dada Mail - Pure Perl version included, but you probably want to use a faster version
 
 URI::GoogleChart - used for the fancy charts Dada Mail's Tracker plugin uses. 
@@ -80,6 +82,10 @@ Captcha::reCAPTCHA::Mailhide
 
 DBI - actually a required module, but we assume the environment Dada Mail is installed on has this already (I know, never assume!)
 
+XML::FeedPP - for sending out RSS feeds as mass mailings
+
+Time::Piece - used in templates for http://dadamailproject.com/d/features-email_template_syntax.pod.html#Flexible-Date-and-Time-formats
+
 XMLRPC::Lite
 
 Cwd - for Amazon SES
@@ -92,4 +98,5 @@ MIME::Base64 - for Amazon SES
 
 Crypt::SSLeay - for Amazon SES
 
-XML::LibXML - for Amazon SES
\ No newline at end of file
+XML::LibXML - for Amazon SES
+
